@@ -1,5 +1,7 @@
 package Pod::Weaver;
-our $VERSION = '3.100710';
+BEGIN {
+  $Pod::Weaver::VERSION = '3.101270';
+}
 use Moose;
 # ABSTRACT: weave together a Pod document from an outline
 
@@ -8,11 +10,11 @@ use namespace::autoclean;
 
 use Log::Dispatchouli 1.100710; # proxy
 use Moose::Autobox 0.10;
-use Pod::Elemental;
+use Pod::Elemental 0.100220;
 use Pod::Elemental::Document;
 use Pod::Weaver::Config::Finder;
 use Pod::Weaver::Role::Plugin;
-use String::Flogger;
+use String::Flogger 1;
 
 
 has logger => (
@@ -161,7 +163,7 @@ Pod::Weaver - weave together a Pod document from an outline
 
 =head1 VERSION
 
-version 3.100710
+version 3.101270
 
 =head1 SYNOPSIS
 
